import { request } from "umi";
import type { commonParams } from "@/api/index";

/**
 * 获取应用管理列表
 * @param commonParams
 * @returns
 */
export const GetAppList = (data: commonParams) => {
  return request("/api/appStore/applicationTemplate/list", {
    method: "POST",
    data,
  });
};

/**
 * 获取应用市场列表
 * @param commonParams
 * @returns
 */
export const GetAppPublicList = (data: commonParams) => {
  return request("/api/appStore/public/applicationTemplate/list", {
    method: "POST",
    data,
  });
};

/**
 * 获取应用详情
 * @param commonParams
 * @returns
 */
export const GetAppDetail = (data: { id: string }) => {
  return request("/api/appStore/public/applicationTemplate/detail", {
    method: "POST",
    data,
  });
};

export type AppItem = {
  id?: string;
  name: string;
  applicationId: string;
  icon: string;
  desc: string;
  industries: string;
  applicationScenarios: string;
  tags: string;
  price: number;
  detail: string;
  isOnMarket: boolean;
  isFree: boolean;
  version?: string;
  trialUrl?: string;
};

/**
 * 新增修改应用
 * @param AddItem
 * @returns
 */
export const SaveOrUpdateApp = (data: AppItem) => {
  return request("/api/appStore/applicationTemplate/saveOrUpdate", {
    method: "POST",
    data,
  });
};

/**
 * 上架应用
 * @param ids
 * @returns
 */
export const OnMarketApp = (data: { ids: string[] }) => {
  return request("/api/appStore/applicationTemplate/onMarket", {
    method: "POST",
    data,
  });
};

/**
 * 下架应用
 * @param ids
 * @returns
 */
export const OffMarketApp = (data: { ids: string[] }) => {
  return request("/api/appStore/applicationTemplate/offMarket", {
    method: "POST",
    data,
  });
};

/**
 * 批量删除应用
 * @param ids
 * @returns
 */
export const DeleteAppTemplate = (data: { ids: string[] }) => {
  return request("/api/appStore/applicationTemplate/batchDelete", {
    method: "POST",
    data,
  });
};

/**
 * 批量物理删除应用
 * @param ids
 * @returns
 */
export const ForceDeleteAppTemplate = (data: { ids: string[] }) => {
  return request("/api/appStore/applicationTemplate/forceDelete", {
    method: "POST",
    data,
  });
};
