import { request } from "umi";

export type commonParams = {
  currentPage: number;
  pageSize: number;
  orderByProperty?: string;
  Ascending?: boolean;
  totalPage?: number;
  totalCount?: number;
  filters?: any[];
};

/**
 * 查询多语言
 * @param data {maxCount: number, searchKey: string, searchLan: "zh-CN" | "en"}
 * @returns
 */
export const ListLangBySearchKey = (data: {
  maxCount: number;
  searchKey: string;
  searchLan: "zh-CN" | "en";
}) => {
  return request("/api/system/ListLangBySearchKey", {
    method: "POST",
    data,
  });
};

/**
 * 上传文件
 * @param file 
 * @returns
 */
export const UploadFile = (data: FormData) => {
  return request("/fileApi/File/UploadFiles", {
    method: "POST",
    headers: {
      "Content-Type": "multipart/form-data",
    },
    data,
  });
};

/**
 * 获取文件
 * @param fileId 文件id 
 * @returns
 */
export const GetFile = (data: {fileId: string}) => {
  return request("/File/Download", {
    method: "GET",
    params: data,
    responseType: "blob",
  });
};

/**
 * 获取我的应用
 * @param
 * @returns
 */
export const GetMyAppList = (data: commonParams) => {
  return request("/api/enterprise/myList", {
    method: "POST",
    data,
  });
};

/**
 * 获取当前用户信息
 * @param
 * @returns
 */
export const GetUserInfo = () => {
  return request("/api/account/curUserInfo", {
    method: "POST",
    skipErrorHandler: true
  });
};

/**
 * 获取退出登陆
 * @param
 * @returns
 */
export const Logout = () => {
  return request("/api/account/doLogout", {
    method: "POST",
    skipErrorHandler: true
  });
};
