import { request } from "umi";
import type { commonParams } from "@/api/index";

/**
 * 获取模版管理列表
 * @param commonParams
 * @returns
 */
export const GetTemplateList = (data: commonParams) => {
  return request("/api/templateStore/moduleTemplate/list", {
    method: "POST",
    data,
  });
};

/**
 * 获取模版市场列表
 * @param commonParams
 * @returns
 */
export const GetTemplatePublicList = (data: commonParams) => {
  return request("/api/templateStore/public/moduleTemplate/list", {
    method: "POST",
    data,
  });
};

/**
 * 获取模版详情
 * @param id
 * @returns
 */
export const GetTemplateDetail = (data: { id: string}) => {
  return request("/api/templateStore/public/moduleTemplate/detail", {
    method: "POST",
    data,
  });
};

type AddItem = {
  "name": string,
  "applicationId": string,
  "moduleId": string,
  "type": number, // 模板类型，系统设计、数据模型、页面设计、页面代码、流程模型、文档模型等
  "icon": string,
  "desc": string,
  "industries": string,
  "applicationScenarios": string,
  "tags": string,
  "price": number,
  "detail": string,
  "isOnMarket": boolean,
  "isFree": boolean
}

/**
 * 新增修改模版
 * @param AddItem
 * @returns
 */
export const SaveOrUpdateTemplate = (data: AddItem) => {
  return request("/api/templateStore/moduleTemplate/saveOrUpdate", {
    method: "POST",
    data,
  });
};

/**
 * 上架模版
 * @param ids
 * @returns
 */
export const OnMarketTemplate = (data: {ids: string[]}) => {
  return request("/api/templateStore/moduleTemplate/onMarket", {
    method: "POST",
    data,
  });
};

/**
 * 下架模版
 * @param ids
 * @returns
 */
export const OffMarketTemplate = (data: {ids: string[]}) => {
  return request("/api/templateStore/moduleTemplate/offMarket", {
    method: "POST",
    data,
  });
};

/**
 * 批量删除应用
 * @param ids
 * @returns
 */
export const DeleteTemplate = (data: {ids: string[]}) => {
  return request("/api/templateStore/moduleTemplate/batchDelete", {
    method: "POST",
    data,
  });
};

/**
 * 批量物理删除应用
 * @param ids
 * @returns
 */
export const ForceDeleteTemplate = (data: {ids: string[]}) => {
  return request("/api/templateStore/moduleTemplate/forceDelete", {
    method: "POST",
    data,
  });
};